import React, { ReactInstance } from 'react';
import { Asset } from '@bitwebsvc/lowcode-utils';
import { IPublicTypeComponentSchema, IPublicTypeNodeInstance, IPublicTypeProjectSchema } from '@bitwebsvc/lowcode-types';
import { BuiltinSimulatorRenderer, Component, IDocumentModel, INode } from '@bitwebsvc/lowcode-designer';
import { MemoryHistory } from 'history';
export declare class DocumentInstance {
    readonly container: SimulatorRendererContainer;
    readonly document: IDocumentModel;
    instancesMap: Map<string, ReactInstance[]>;
    get schema(): any;
    private disposeFunctions;
    private _components;
    get components(): object;
    private _appContext;
    get context(): any;
    private _designMode;
    get designMode(): any;
    private _requestHandlersMap;
    get requestHandlersMap(): any;
    private _device;
    get device(): string;
    private _componentsMap;
    get componentsMap(): any;
    get suspended(): any;
    get scope(): any;
    get path(): string;
    get id(): string;
    constructor(container: SimulatorRendererContainer, document: IDocumentModel);
    private unmountInstance;
    mountInstance(id: string, instance: ReactInstance | null): void;
    mountContext(): void;
    getNode(id: string): INode | null;
    dispose(): void;
}
export declare class SimulatorRendererContainer implements BuiltinSimulatorRenderer {
    readonly isSimulatorRenderer = true;
    private disposeFunctions;
    readonly history: MemoryHistory;
    private _documentInstances;
    private _requestHandlersMap;
    get documentInstances(): DocumentInstance[];
    private _layout;
    get layout(): any;
    set layout(value: any);
    private _libraryMap;
    private _components;
    get components(): Record<string, React.FC | React.ComponentClass>;
    private _appContext;
    get context(): any;
    private _designMode;
    get designMode(): any;
    private _device;
    get device(): string;
    private _locale;
    get locale(): string;
    private _componentsMap;
    get componentsMap(): any;
    /**
     * 是否为画布自动渲染
     */
    autoRender: boolean;
    /**
     * 画布是否自动监听事件来重绘节点
     */
    autoRepaintNode: boolean;
    private _running;
    constructor();
    private buildComponents;
    /**
     * 加载资源
     */
    load(asset: Asset): Promise<any>;
    loadAsyncLibrary(asyncLibraryMap: Record<string, any>): Promise<void>;
    getComponent(componentName: string): any;
    getClosestNodeInstance(from: ReactInstance, nodeId?: string): IPublicTypeNodeInstance<ReactInstance> | null;
    findDOMNodes(instance: ReactInstance): Array<Element | Text> | null;
    getClientRects(element: Element | Text): DOMRect[];
    setNativeSelection(enableFlag: boolean): void;
    setDraggingState(state: boolean): void;
    setCopyState(state: boolean): void;
    clearState(): void;
    createComponent(schema: IPublicTypeProjectSchema<IPublicTypeComponentSchema>): Component | null;
    run(): void;
    /**
     * 刷新渲染器
     */
    rerender(): void;
    stopAutoRepaintNode(): void;
    enableAutoRepaintNode(): void;
    dispose(): void;
}
declare const _default: SimulatorRendererContainer;
export default _default;
