/**
 * Parse queryString
 * @param  {String} str '?q=query&b=test'
 * @return {Object}
 */
export function parseQuery(str) {
  var ret = {};
  if (typeof str !== 'string') {
    return ret;
  }
  var s = str.trim().replace(/^(\?|#|&)/, '');
  if (!s) {
    return ret;
  }
  s.split('&').forEach(function (param) {
    var parts = param.replace(/\+/g, ' ').split('=');
    var key = parts.shift();
    var val = parts.length > 0 ? parts.join('=') : undefined;
    key = decodeURIComponent(key);
    val = val === undefined ? null : decodeURIComponent(val);
    if (ret[key] === undefined) {
      ret[key] = val;
    } else if (Array.isArray(ret[key])) {
      ret[key].push(val);
    } else {
      ret[key] = [ret[key], val];
    }
  });
  return ret;
}

/**
 * Stringify object to query parammeters
 * @param  {Object} obj
 * @return {String}
 */
export function stringifyQuery(obj) {
  var param = [];
  Object.keys(obj).forEach(function (key) {
    var value = obj[key];
    if (value && typeof value === 'object') {
      value = JSON.stringify(value);
    }
    param.push(encodeURIComponent(key) + "=" + encodeURIComponent(value));
  });
  return param.join('&');
}
export function uriEncode(uri) {
  return encodeURIComponent(uri);
}
export function uriDecode(uri) {
  return decodeURIComponent(uri);
}
export function withQueryParams(url, params) {
  var queryStr = params ? stringifyQuery(params) : '';
  if (queryStr === '') {
    return url;
  }
  var urlSplit = url.split('#');
  var hash = urlSplit[1] ? "#" + urlSplit[1] : '';
  var urlWithoutHash = urlSplit[0];
  return "" + urlWithoutHash + (~urlWithoutHash.indexOf('?') ? '&' : '?') + queryStr + hash;
}